isExpanded property
bool
get
isExpanded
Whether the window shows the full readout instead of the compact chip.
Implementation
bool get isExpanded => _isExpanded;
Whether the window shows the full readout instead of the compact chip.
bool get isExpanded => _isExpanded;