moveTo method
Moves the window. The offset is not clamped here; the window clamps it to the current viewport while it lays out.
Implementation
void moveTo(Offset offset) {
if (_offset == offset) return;
_offset = offset;
_notify();
}
Moves the window. The offset is not clamped here; the window clamps it to the current viewport while it lays out.
void moveTo(Offset offset) {
if (_offset == offset) return;
_offset = offset;
_notify();
}