offset property
Offset?
get
offset
Top-left corner chosen by the user, or null for the default position.
Implementation
Offset? get offset => _offset;
Top-left corner chosen by the user, or null for the default position.
Offset? get offset => _offset;