setExpanded method
Switches between the full readout and the compact chip.
Implementation
void setExpanded(bool expanded) {
if (_isExpanded == expanded) return;
_isExpanded = expanded;
_storage.writeBool(_expandedKey, expanded);
_notify();
}
Switches between the full readout and the compact chip.
void setExpanded(bool expanded) {
if (_isExpanded == expanded) return;
_isExpanded = expanded;
_storage.writeBool(_expandedKey, expanded);
_notify();
}