badColorDefault constant
Color
const badColorDefault
Default color for a metric that is far outside the expected range.
Implementation
static const badColorDefault = Color(0xFFD8674B);
Default color for a metric that is far outside the expected range.
static const badColorDefault = Color(0xFFD8674B);