goodColorIn method
The healthy color, resolved against scheme when none was configured.
Implementation
Color goodColorIn(ColorScheme scheme) => goodColor ?? scheme.primary;
The healthy color, resolved against scheme when none was configured.
Color goodColorIn(ColorScheme scheme) => goodColor ?? scheme.primary;