otherColorDefault constant
Color
const otherColorDefault
Default color of the segment that is neither build nor raster.
Implementation
static const otherColorDefault = Color(0x4A747871);
Default color of the segment that is neither build nor raster.
static const otherColorDefault = Color(0x4A747871);