rasterColorDefault constant
Color
const rasterColorDefault
Default color of the raster thread segment of a frame bar.
Implementation
static const rasterColorDefault = Color(0xFF2FBF8F);
Default color of the raster thread segment of a frame bar.
static const rasterColorDefault = Color(0xFF2FBF8F);