warnColorDefault constant
Color
const warnColorDefault
Default color for a metric that left the expected range a little.
Implementation
static const warnColorDefault = Color(0xFFB07A1F);
Default color for a metric that left the expected range a little.
static const warnColorDefault = Color(0xFFB07A1F);