SharedPreferencesHudStorage constructor
SharedPreferencesHudStorage()
Creates a storage that opens the platform store on load.
Implementation
SharedPreferencesHudStorage();
Creates a storage that opens the platform store on load.
SharedPreferencesHudStorage();